@@ -14,6 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Sequence
 
@@ -33,13 +34,9 @@ class ADLSDeleteOperator(BaseOperator):
             :ref:`howto/operator:ADLSDeleteOperator`
 
     :param path: A directory or file to remove
-    :type path: str
     :param recursive: Whether to loop into directories in the location and remove the files
-    :type recursive: bool
     :param ignore_not_found: Whether to raise error if file to delete is not found
-    :type ignore_not_found: bool
     :param azure_data_lake_conn_id: Reference to the :ref:`Azure Data Lake connection<howto/connection:adl>`.
-    :type azure_data_lake_conn_id: str
     """
 
     template_fields: Sequence[str] = ('path',)
@@ -60,7 +57,7 @@ class ADLSDeleteOperator(BaseOperator):
         self.ignore_not_found = ignore_not_found
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
-    def execute(self, context: "Context") -> Any:
+    def execute(self, context: Context) -> Any:
         hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
         return hook.remove(path=self.path, recursive=self.recursive, ignore_not_found=self.ignore_not_found)
 
@@ -74,9 +71,7 @@ class ADLSListOperator(BaseOperator):
 
     :param path: The Azure Data Lake path to find the objects. Supports glob
         strings (templated)
-    :type path: str
     :param azure_data_lake_conn_id: Reference to the :ref:`Azure Data Lake connection<howto/connection:adl>`.
-    :type azure_data_lake_conn_id: str
 
     **Example**:
         The following Operator would list all the Parquet files from ``folder/output/``
@@ -99,7 +94,7 @@ class ADLSListOperator(BaseOperator):
         self.path = path
         self.azure_data_lake_conn_id = azure_data_lake_conn_id
 
-    def execute(self, context: "Context") -> list:
+    def execute(self, context: Context) -> list:
         hook = AzureDataLakeHook(azure_data_lake_conn_id=self.azure_data_lake_conn_id)
         self.log.info('Getting list of ADLS files in path: %s', self.path)
         return hook.list(path=self.path)
