@@ -15,6 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
@@ -30,14 +32,10 @@ class AzureCosmosInsertDocumentOperator(BaseOperator):
     It will create both the database and collection if they do not already exist
 
     :param database_name: The name of the database. (templated)
-    :type database_name: str
     :param collection_name: The name of the collection. (templated)
-    :type collection_name: str
     :param document: The document to insert
-    :type document: dict
     :param azure_cosmos_conn_id: Reference to the
         :ref:`Azure CosmosDB connection<howto/connection:azure_cosmos>`.
-    :type azure_cosmos_conn_id: str
     """
 
     template_fields: Sequence[str] = ('database_name', 'collection_name')
@@ -58,7 +56,7 @@ class AzureCosmosInsertDocumentOperator(BaseOperator):
         self.document = document
         self.azure_cosmos_conn_id = azure_cosmos_conn_id
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         # Create the hook
         hook = AzureCosmosDBHook(azure_cosmos_conn_id=self.azure_cosmos_conn_id)
 
